summaryrefslogtreecommitdiff
path: root/lib/rssaction.php
diff options
context:
space:
mode:
authorEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:12:20 -0400
committerEvan Prodromou <evan@controlyourself.ca>2009-08-25 18:12:20 -0400
commitc8b8f07af14ad2ce9d0c0267962dd3bbf6473a4b (patch)
tree2ed665ca0639c845f425c671fdffccc01e6ddc3a /lib/rssaction.php
parentd0baab6978f1959382d568d26cc9f8f552a7b764 (diff)
change Laconica and Control Yourself to StatusNet in PHP files
Diffstat (limited to 'lib/rssaction.php')
-rw-r--r--lib/rssaction.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/rssaction.php b/lib/rssaction.php
index 0aca96566..21d85144d 100644
--- a/lib/rssaction.php
+++ b/lib/rssaction.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Base class for RSS 1.0 feed actions
*
@@ -20,10 +20,10 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Mail
- * @package Laconica
+ * @package StatusNet
* @author Evan Prodromou <evan@controlyourself.ca>
* @author Earle Martin <earle@downlode.org>
- * @copyright 2008-9 Control Yourself, Inc.
+ * @copyright 2008-9 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
* @link http://laconi.ca/
*/
@@ -102,7 +102,7 @@ class Rss10Action extends Action
if (!isset($_SERVER['PHP_AUTH_USER'])) {
# This header makes basic auth go
- header('WWW-Authenticate: Basic realm="Laconica RSS"');
+ header('WWW-Authenticate: Basic realm="StatusNet RSS"');
# If the user hits cancel -- bam!
$this->show_basic_auth_error();
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Base class for RSS 1.0 feed actions